#' @name BracarensePg114
#' @title Intenções de Voto
#' @description Pesquisas de intençõeses de voto feitas para eleição da
#'     Bahia em 2006, em diferentes datas antes da eleição.
#' @format Um \code{data.frame} com 8 linhas e 4 colunas em que:
#'
#' \describe{
#'
#' \item{\code{Data}}{Data de divulgação das pesquisar de inteção de
#'     voto ou do resultado final das eleições.}
#'
#' \item{\code{PS}}{Porcentagem de votos para Paulo Souto.}
#'
#' \item{\code{JW}}{Porcentagem de votos para Jaques Wagner.}
#'
#' \item{\code{OC}}{Porcentagem de votos para outros candidatos.}
#'
#' }
#' @keywords estat?stica b?sica
#' @source BRACARENSE (2009), exemplo p?gina 114.
#' @examples
#'
#' data(BracarensePg114)
#' str(BracarensePg114)
#'
#' # Porque algumas somas passam de 100%?
#' rowSums(BracarensePg114[, -1])
#'
#' BracarensePg114$Data <- factor(BracarensePg114$Data,
#'                                levels = as.character(BracarensePg114$Data))
#'
#' dados <- c(BracarensePg114$PS[c(1, 8)], BracarensePg114$JW[c(1, 8)])
#'
#' barplot(dados,
#'         names.arg = rep(c("Paulo Souto",
#'                           "Jaques Wagner"), each = 2),
#'         col = rep(c("red", "pink"), times = 2),
#'         main = paste0("Intenções de Voto em 18/5\n",
#'                       "Comparadas com o Resultado Final da Eleições"),
#'         ylim = c(0, 80),
#'         legend = c("18/5", "Resultado Oficial"))
#'
#' library(lattice)
#' library(latticeExtra)
#'
#' barchart(PS + JW + OC ~ Data, data = BracarensePg114)
#'
#' barchart(~PS + JW + OC | Data,
#'          data = BracarensePg114,
#'          as.table = TRUE)
#'
#' xyplot(PS + JW + OC ~ Data,
#'        data = BracarensePg114,
#'        xlab = "Datas das pesquisas e resultado final",
#'        ylab = "Proporção de votos (%)",
#'        type = "o",
#'        pch = 19) +
#'     layer(panel.text(x = tapply(x, groups, tail, 1),
#'                      y = tapply(y, groups, tail, 1),
#'                      labels = levels(groups),
#'                      pos = 4, cex = 1.1))
#'
NULL
